@@ -32,10 +32,8 @@ import com.unciv.models.Counter
 import com.unciv.models.ruleset.Belief
 import com.unciv.models.ruleset.BeliefType
 import com.unciv.models.ruleset.Building
-import com.unciv.models.ruleset.INonPerpetualConstruction
 import com.unciv.models.ruleset.MilestoneType
 import com.unciv.models.ruleset.ModOptionsConstants
-import com.unciv.models.ruleset.PerpetualConstruction
 import com.unciv.models.ruleset.Policy
 import com.unciv.models.ruleset.PolicyBranch
 import com.unciv.models.ruleset.Victory
@@ -47,8 +45,6 @@ import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.stats.Stat
 import com.unciv.models.translations.tr
 import com.unciv.ui.screens.victoryscreen.RankingType
-import java.util.SortedMap
-import java.util.TreeMap
 import kotlin.math.min
 import kotlin.random.Random
 
@@ -84,7 +80,7 @@ object NextTurnAutomation {
 
         chooseTechToResearch(civInfo)
         automateCityBombardment(civInfo)
-        useGold(civInfo)
+        UseGoldAutomation.useGold(civInfo)
         if (!civInfo.isCityState()) {
             protectCityStates(civInfo)
             bullyCityStates(civInfo)
@@ -291,149 +287,6 @@ object NextTurnAutomation {
         civInfo.popupAlerts.clear() // AIs don't care about popups.
     }
 
-    private fun tryGainInfluence(civInfo: Civilization, cityState: Civilization) {
-        if (civInfo.gold < 250) return // save up
-        if (cityState.getDiplomacyManager(civInfo).getInfluence() < 20) {
-            cityState.cityStateFunctions.receiveGoldGift(civInfo, 250)
-            return
-        }
-        if (civInfo.gold < 500) return // it's not worth it to invest now, wait until you have enough for 2
-        cityState.cityStateFunctions.receiveGoldGift(civInfo, 500)
-        return
-    }
-
-    private fun useGoldForCityStates(civ: Civilization) {
-        // RARE EDGE CASE: If you ally with a city-state, you may reveal more map that includes ANOTHER civ!
-        // So if we don't lock this list, we may later discover that there are more known civs, concurrent modification exception!
-        val knownCityStates = civ.getKnownCivs().filter { it.isCityState() }.toList()
-
-        // canBeMarriedBy checks actual cost, but it can't be below 500*speedmodifier, and the later check is expensive
-        if (civ.gold >= 330 && civ.getHappiness() > 0 && civ.hasUnique(UniqueType.CityStateCanBeBoughtForGold)) {
-            for (cityState in knownCityStates.toList() ) {  // Materialize sequence as diplomaticMarriage may kill a CS
-                if (cityState.cityStateFunctions.canBeMarriedBy(civ))
-                    cityState.cityStateFunctions.diplomaticMarriage(civ)
-                if (civ.getHappiness() <= 0) break // Stop marrying if happiness is getting too low
-            }
-        }
-
-        if (civ.gold < 250) return  // skip checks if tryGainInfluence will bail anyway
-        if (civ.wantsToFocusOn(Victory.Focus.Culture)) {
-            for (cityState in knownCityStates.filter { it.cityStateFunctions.canProvideStat(Stat.Culture) }) {
-                val diploManager = cityState.getDiplomacyManager(civ)
-                if (diploManager.getInfluence() < 40) { // we want to gain influence with them
-                    tryGainInfluence(civ, cityState)
-                }
-            }
-        }
-
-        if (civ.gold < 250 || knownCityStates.none()) return
-        val cityState = knownCityStates
-            .filter { it.getAllyCiv() != civ.civName }
-            .associateWith { valueCityStateAlliance(civ, it) }
-            .maxByOrNull { it.value }?.takeIf { it.value > 0 }?.key
-        if (cityState != null) {
-            tryGainInfluence(civ, cityState)
-        }
-    }
-
-    /** allow AI to spend money to purchase city-state friendship, buildings & unit */
-    private fun useGold(civ: Civilization) {
-        if (civ.isMajorCiv())
-            useGoldForCityStates(civ)
-
-        for (city in civ.cities.sortedByDescending { it.population.population }) {
-            val construction = city.cityConstructions.getCurrentConstruction()
-            if (construction is PerpetualConstruction) continue
-            if ((construction as INonPerpetualConstruction).canBePurchasedWithStat(city, Stat.Gold)
-                    && city.civ.gold / 3 >= construction.getStatBuyCost(city, Stat.Gold)!!) {
-                city.cityConstructions.purchaseConstruction(construction, 0, true)
-            }
-        }
-
-        maybeBuyCityTiles(civ)
-    }
-
-    private fun maybeBuyCityTiles(civInfo: Civilization) {
-        if (civInfo.gold <= 0)
-            return
-        // Don't buy tiles in the very early game. It is unlikely that we already have the required
-        // tech, the necessary worker and that there is a reasonable threat from another player to
-        // grab the tile. We could also check all that, but it would require a lot of cycles each
-        // turn and this is probably a good approximation.
-        if (civInfo.gameInfo.turns < (civInfo.gameInfo.speed.scienceCostModifier * 20).toInt())
-            return
-
-        val highlyDesirableTiles: SortedMap<Tile, MutableSet<City>> = TreeMap(
-            compareByDescending<Tile?> { it?.naturalWonder != null }
-                .thenByDescending { it?.resource != null && it.tileResource.resourceType == ResourceType.Luxury }
-                .thenByDescending { it?.resource != null && it.tileResource.resourceType == ResourceType.Strategic }
-                // This is necessary, so that the map keeps Tiles with the same resource as two
-                // separate entries.
-                .thenBy { it.hashCode() }
-        )
-        for (city in civInfo.cities.filter { !it.isPuppet && !it.isBeingRazed }) {
-            val highlyDesirableTilesInCity = city.tilesInRange.filter {
-                val hasNaturalWonder = it.naturalWonder != null
-                val hasLuxuryCivDoesntOwn =
-                    it.hasViewableResource(civInfo)
-                        && it.tileResource.resourceType == ResourceType.Luxury
-                        && !civInfo.hasResource(it.resource!!)
-                val hasResourceCivHasNoneOrLittle =
-                    it.hasViewableResource(civInfo)
-                        && it.tileResource.resourceType == ResourceType.Strategic
-                        && civInfo.getResourceAmount(it.resource!!) <= 3
-
-                it.isVisible(civInfo) && it.getOwner() == null
-                    && it.neighbors.any { neighbor -> neighbor.getCity() == city }
-                (hasNaturalWonder || hasLuxuryCivDoesntOwn || hasResourceCivHasNoneOrLittle)
-            }
-            for (highlyDesirableTileInCity in highlyDesirableTilesInCity) {
-                highlyDesirableTiles.getOrPut(highlyDesirableTileInCity) { mutableSetOf() }
-                    .add(city)
-            }
-        }
-
-        // Always try to buy highly desirable tiles if it can be afforded.
-        for (highlyDesirableTile in highlyDesirableTiles) {
-            val cityWithLeastCostToBuy = highlyDesirableTile.value.minBy {
-                it.getCenterTile().aerialDistanceTo(highlyDesirableTile.key)
-            }
-            val bfs = BFS(cityWithLeastCostToBuy.getCenterTile())
-            {
-                it.getOwner() == null || it.owningCity == cityWithLeastCostToBuy
-            }
-            bfs.stepUntilDestination(highlyDesirableTile.key)
-            val tilesThatNeedBuying =
-                    bfs.getPathTo(highlyDesirableTile.key).filter { it.getOwner() == null }
-                        .toList().reversed() // getPathTo is from destination to source
-
-            // We're trying to acquire everything and revert if it fails, because of the difficult
-            // way how tile acquisition cost is calculated. Everytime you buy a tile, the next one
-            // gets more expensive and by how much depends on other things such as game speed. To
-            // not introduce hidden dependencies on that and duplicate that logic here to calculate
-            // the price of the whole path, this is probably simpler.
-            var ranOutOfMoney = false
-            var goldSpent = 0
-            for (tileThatNeedsBuying in tilesThatNeedBuying) {
-                val goldCostOfTile =
-                        cityWithLeastCostToBuy.expansion.getGoldCostOfTile(tileThatNeedsBuying)
-                if (civInfo.gold >= goldCostOfTile) {
-                    cityWithLeastCostToBuy.expansion.buyTile(tileThatNeedsBuying)
-                    goldSpent += goldCostOfTile
-                } else {
-                    ranOutOfMoney = true
-                    break
-                }
-            }
-            if (ranOutOfMoney) {
-                for (tileThatNeedsBuying in tilesThatNeedBuying) {
-                    cityWithLeastCostToBuy.expansion.relinquishOwnership(tileThatNeedsBuying)
-                }
-                civInfo.addGold(goldSpent)
-            }
-        }
-    }
-
     internal fun valueCityStateAlliance(civInfo: Civilization, cityState: Civilization): Int {
         var value = 0
 
@@ -532,7 +385,7 @@ object NextTurnAutomation {
         if (civInfo.tech.techsToResearch.isEmpty()) {
             val costs = getGroupedResearchableTechs()
             if (costs.isEmpty()) return
-            
+
             val cheapestTechs = costs[0]
             //Do not consider advanced techs if only one tech left in cheapest group
             val techToResearch: Technology =
@@ -627,7 +480,7 @@ object NextTurnAutomation {
                 continue
 
             val unitToDisband = civInfo.units.getCivUnits()
-                .filter { it.baseUnit.requiresResource(resource) }
+                .filter { it.requiresResource(resource) }
                 .minByOrNull { it.getForceEvaluation() }
             unitToDisband?.disband()
 
@@ -636,7 +489,7 @@ object NextTurnAutomation {
                     continue
                 val buildingToSell = civInfo.gameInfo.ruleset.buildings.values.filter {
                         city.cityConstructions.isBuilt(it.name)
-                        && it.requiresResource(resource)
+                        && it.requiresResource(resource, StateForConditionals(civInfo, city))
                         && it.isSellable()
                         && !civInfo.civConstructions.hasFreeBuilding(city, it) }
                     .randomOrNull()
