@@ -1,15 +1,29 @@
 package com.unciv.models.ruleset.unique
 
+import com.unciv.models.stats.INamed
+
 /**
  * Common interface for all 'ruleset objects' that have Uniques, like BaseUnit, Nation, etc.
  */
-interface IHasUniques {
+interface IHasUniques : INamed {
     var uniques: ArrayList<String> // Can not be a hashset as that would remove doubles
-    // I bet there's a way of initializing these without having to override it everywhere...
-    val uniqueObjects: List<Unique>
 
+    // Every implementation should override these with the same `by lazy (::thingsProvider)`
+    // AND every implementation should annotate these with `@delegate:Transient`
+    val uniqueObjects: List<Unique>
     val uniqueMap: Map<String, List<Unique>>
 
+    fun uniqueObjectsProvider(): List<Unique> {
+        if (uniques.isEmpty()) return emptyList()
+        return uniques.map { Unique(it, getUniqueTarget(), name) }
+    }
+    fun uniqueMapProvider(): UniqueMap {
+        val newUniqueMap = UniqueMap()
+        if (uniques.isNotEmpty())
+            newUniqueMap.addUniques(uniqueObjects)
+        return newUniqueMap
+    }
+
     /** Technically not currently needed, since the unique target can be retrieved from every unique in the uniqueObjects,
      * But making this a function is relevant for future "unify Unciv object" plans ;)
      * */
@@ -29,4 +43,3 @@ interface IHasUniques {
     fun hasUnique(uniqueType: UniqueType, stateForConditionals: StateForConditionals? = null) =
         getMatchingUniques(uniqueType.placeholderText, stateForConditionals).any()
 }
-
