@@ -12,8 +12,8 @@ import com.unciv.models.ruleset.unique.UniqueFlag
 import com.unciv.models.ruleset.unique.UniqueType
 import com.unciv.models.ruleset.unit.BaseUnit
 import com.unciv.models.translations.tr
-import com.unciv.ui.components.Fonts
 import com.unciv.ui.components.extensions.center
+import com.unciv.ui.components.fonts.Fonts
 import com.unciv.ui.images.ImageGetter
 import com.unciv.ui.images.PortraitUnavailableWonderForTechTree
 import com.unciv.ui.screens.civilopediascreen.FormattedLine
@@ -30,6 +30,14 @@ object TechnologyDescriptions {
     fun getDescription(technology: Technology, viewingCiv: Civilization): String = technology.run {
         val ruleset = viewingCiv.gameInfo.ruleset
         val lineList = ArrayList<String>() // more readable than StringBuilder, with same performance for our use-case
+
+        for (pediaText in technology.civilopediaText) {
+            // This is explicitly to get the "Who knows what the future holds" of Future Tech back into
+            // the Tech Picker and Tech Researched Alert display, without making it an untyped Unique.
+            // May need tuning for mods, in vanilla there is just the one case.
+            if (pediaText.text.isEmpty() || pediaText.header != 0) continue
+            lineList += pediaText.text
+        }
         for (unique in uniques) lineList += unique
 
         lineList.addAll(
@@ -100,7 +108,7 @@ object TechnologyDescriptions {
                     // doesn't have the tech, so it can't have this built anyways. It should be a
                     // little more performant though to add this filter.
                     .filter{ it.civ != viewingCiv }
-                    .any { it.cityConstructions.builtBuildings.contains(building.name) }
+                    .any { it.cityConstructions.isBuilt(building.name)}
                 val wonderConstructionPortrait =
                         if (isAlreadyBuilt)
                             PortraitUnavailableWonderForTechTree(building.name, techIconSize)
